brg

Add support for cast ... to bool in visitCastInst (it's a start, anyways...)


git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@4883 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/Target/X86/InstSelectSimple.cpp b/lib/Target/X86/InstSelectSimple.cpp
index a601660..ac4084c 100644
--- a/lib/Target/X86/InstSelectSimple.cpp
+++ b/lib/Target/X86/InstSelectSimple.cpp
@@ -641,9 +641,20 @@
 //the former is that the register allocator could use any register it wants,
 //but for now this obviously doesn't matter.  :)
 
-// if target type is bool
-// Emit Compare
-// Emit Set-if-not-zero
+  Type *targetType = CI.getType ();
+  Value *operand = CI.getOperand (0);
+  unsigned int operandReg = getReg (operand);
+  Type *sourceType = operand->getType ();
+  unsigned int destReg = getReg (CI);
+
+  // cast to bool:
+  if (targetType == Type::BoolTy) {
+    // Emit Compare
+    BuildMI (BB, X86::CMPri8, 2).addReg (operandReg).addZImm (0);
+    // Emit Set-if-not-zero
+    BuildMI (BB, X86::SETNEr, 1, destReg);
+    return;
+  }
 
 // if size of target type == size of source type
 // Emit Mov reg(target) <- reg(source)